==> xiphos_4.2.1+dfsg1.orig.tar.xz: xiphos-4.2.1+dfsg1/src/editor/template.h <==
/*
 * Xiphos Bible Study Tool
 * template.h - data for studypad template (webkit editor)
 *
 *  ** this is used by settings only if studypad.spt does not exist **
 * 
 * Copyright (C) 2005-2020 Xiphos Developer Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#define studypad_template \
	"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n\
<html>\n\
<head>\n\
<title>studypad template</title>\n\
<meta name=\"generator\" content=\"Studypad\">\n\
<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n\
<meta http-equiv=\"content-type\" content=\"application/xhtml+xml; charset=UTF-8\">\n\
<meta http-equiv=\"content-style-type\" content=\"text/css\">\n\
<meta http-equiv=\"expires\" content=\"0\">\n\
<style content=\"text/css\">\n\
 a { text-decoration:none; } \n\
 span.M1 { \n\
 	font-family:Droid Sans,sans-serif; \n\
 	font-size: 14px; \n\
 	font-weight: normal; \n\
 } \n\
 span.acrostic             { text-align: center; } \n\
 span.divineName           { font-variant: small-caps; } \n\
 span.selah                { text-align: right; width: 50%; margin: 0; padding: 0; } \n\
 span.small-caps           { font-variant: small-caps; } \n\
 span.transChangeSupplied  { font-style: italic; } \n\
 span.wordsOfJesus         { color: red; } \n\
ol.L1 { \n\
	list-style-type: upper-roman; \n\
	font-weight: normal; \n\
	margin-left: -10px; \n\
} \n\
ol.L2 { \n\
	list-style-type: upper-alpha; \n\
	font-weight: normal; \n\
	margin-left: -6px; \n\
} \n\
ol.L3 { \n\
	list-style-type: decimal; \n\
	font-weight: normal; \n\
	margin-left: 5px; \n\
} \n\
ol.L4 { \n\
	list-style-type: lower-alpha; \n\
	font-weight: normal; \n\
	margin-left: 10px; \n\
} \n\
</style>\n\
</head>\n\
<body>\n\
\n\
</body>\n\
</html>\n"

==> xiphos_4.3.2+dfsg1.orig.tar.xz: xiphos-4.3.2/src/editor/template.h <==
/*
 * Xiphos Bible Study Tool
 * template.h - data for studypad template (webkit editor)
 *
 *  ** this is used by settings only if studypad.spt does not exist **
 * 
 * Copyright (C) 2005-2025 Xiphos Developer Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#define studypad_template \
	"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\n\
<html>\n\
<head>\n\
<title>studypad template</title>\n\
<meta name=\"generator\" content=\"Studypad\" />\n\
<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\" />\n\
<meta http-equiv=\"content-type\" content=\"application/xhtml+xml; charset=UTF-8\" />\n\
<meta http-equiv=\"content-style-type\" content=\"text/css\" />\n\
<meta http-equiv=\"expires\" content=\"0\" />\n\
<style content=\"text/css\">\n\
 a { text-decoration:none; } \n\
 span.M1 { \n\
 	font-family:Droid Sans,sans-serif; \n\
 	font-size: 14px; \n\
 	font-weight: normal; \n\
 } \n\
 span.acrostic             { text-align: center; } \n\
 span.divineName           { font-variant: small-caps; } \n\
 span.selah                { text-align: right; width: 50%; margin: 0; padding: 0; } \n\
 span.small-caps           { font-variant: small-caps; } \n\
 span.transChangeSupplied  { font-style: italic; } \n\
 span.wordsOfJesus         { color: red; } \n\
ol.L1 { \n\
	list-style-type: upper-roman; \n\
	font-weight: normal; \n\
	margin-left: -10px; \n\
} \n\
ol.L2 { \n\
	list-style-type: upper-alpha; \n\
	font-weight: normal; \n\
	margin-left: -6px; \n\
} \n\
ol.L3 { \n\
	list-style-type: decimal; \n\
	font-weight: normal; \n\
	margin-left: 5px; \n\
} \n\
ol.L4 { \n\
	list-style-type: lower-alpha; \n\
	font-weight: normal; \n\
	margin-left: 10px; \n\
} \n\
</style>\n\
</head>\n\
<body>\n\
\n\
</body>\n\
</html>\n"
